==> haskell-x11-xft-0.3.1-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11-xft
version: 0.3.1
id: X11-xft-0.3.1-K4niwLcixMDE8kcmPvf2YY
key: X11-xft-0.3.1-K4niwLcixMDE8kcmPvf2YY
license: LicenseRef-LGPL
maintainer: clemens@endorphin.org
author: Clemens Fruhwirth
synopsis: Bindings to the Xft, X Free Type interface library, and some Xrender parts
description:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts
category: Graphics
abi: 94525e47339ef193592747b8219c792e
exposed: True
exposed-modules:
    Graphics.X11.Xft Graphics.X11.Xrender
import-dirs: /usr/lib/ghc-8.6.4/site-local/X11-xft-0.3.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/X11-xft-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/X11-xft-0.3.1
hs-libraries: HSX11-xft-0.3.1-K4niwLcixMDE8kcmPvf2YY
extra-libraries:
    Xft
include-dirs: /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/uuid
depends:
    X11-1.9-BvfkNPYen6XHZbcGySTCaQ base-4.12.0.0
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html: /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-xft-0.3.1-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11-xft
version: 0.3.1
id: X11-xft-0.3.1-AMgvCrCGdzgC3OcfXpzTX3
key: X11-xft-0.3.1-AMgvCrCGdzgC3OcfXpzTX3
license: LicenseRef-LGPL
maintainer: clemens@endorphin.org
author: Clemens Fruhwirth
synopsis: Bindings to the Xft, X Free Type interface library, and some Xrender parts
description:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts
category: Graphics
abi: 745f6acce423c927ce5588f04021ecc7
exposed: True
exposed-modules:
    Graphics.X11.Xft Graphics.X11.Xrender
import-dirs: /usr/lib/ghc-8.6.4/site-local/X11-xft-0.3.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/X11-xft-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/X11-xft-0.3.1
hs-libraries: HSX11-xft-0.3.1-AMgvCrCGdzgC3OcfXpzTX3
extra-libraries:
    Xft
include-dirs: /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/uuid
depends:
    X11-1.9-8X00zzCjMe13z8AbgluigM base-4.12.0.0
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html: /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
